"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const clone_1 = require("./clone");
const clone_error_1 = require("./clone-error");
/**
 * Returns a cloneable copy of the given context object.
 * @internal
 */
function cloneContext(context) {
    return {
        cwd: context.cwd,
        dev: context.dev,
        debug: context.debug,
    };
}
exports.cloneContext = cloneContext;
/**
 * Creates a `Context` object from a `ContextClone`.
 * @internal
 */
function createContext(messenger, messageId, context) {
    return {
        ...context,
        logger: {
            log(message, data) {
                messenger.postReply(createLogReply("info", messageId, message, data));
            },
            debug(message, data) {
                if (context.debug) {
                    messenger.postReply(createLogReply("debug", messageId, message, data));
                }
            },
            warn(message, data) {
                messenger.postReply(createLogReply("warning", messageId, message, data));
            },
            error(message, data) {
                messenger.postReply(createLogReply("error", messageId, message, data));
            }
        }
    };
}
exports.createContext = createContext;
function createLogReply(level, to, msg, obj) {
    let message = typeof msg === "string" ? msg : clone_error_1.cloneError(msg);
    let data = obj && clone_1.clone(obj);
    return { type: "log", to, level, message, data };
}
//# sourceMappingURL=clone-context.js.map