"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const clone_error_1 = require("../clone/clone-error");
/**
 * Allows an `Executor` to handle and reply to messages from a `Worker`.
 * @internal
 */
class Messenger {
    constructor(port) {
        this._port = port;
        port.on("message", this._handleMessage.bind(this));
    }
    /**
     * Replies to a message from the `Worker`.
     */
    postReply(reply) {
        this._port.postMessage(reply);
    }
    /**
     * Handles incoming messages from the `Worker`.
     */
    async _handleMessage(message) {
        try {
            // tslint:disable-next-line: switch-default
            switch (message.type) {
                case "loadModule":
                    await this.loadModule(message);
                    break;
                case "processFile":
                    await this.processFile(message);
                    break;
            }
        }
        catch (error) {
            // Something went wrong while handling the message, so reply with an error.
            this.postReply({ to: message.id, type: "error", error: clone_error_1.cloneError(error) });
        }
    }
}
exports.Messenger = Messenger;
//# sourceMappingURL=messenger.js.map